v1_4

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2026 License: Apache-2.0 Imports: 10 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToIgn3_3Bytes

func ToIgn3_3Bytes(input []byte, options common.TranslateBytesOptions) ([]byte, report.Report, error)

ToIgn3_3Bytes translates from a v1.4 Butane config to a v3.3.0 Ignition config. It returns a report of any errors or warnings in the source and resultant config. If the report has fatal errors or it encounters other problems translating, an error is returned.

Types

type BootDevice

type BootDevice struct {
	Layout *string          `yaml:"layout"`
	Luks   BootDeviceLuks   `yaml:"luks"`
	Mirror BootDeviceMirror `yaml:"mirror"`
}

func (BootDevice) Validate

func (d BootDevice) Validate(c path.ContextPath) (r report.Report)

type BootDeviceLuks

type BootDeviceLuks struct {
	Tang      []base.Tang `yaml:"tang"`
	Threshold *int        `yaml:"threshold"`
	Tpm2      *bool       `yaml:"tpm2"`
}

type BootDeviceMirror

type BootDeviceMirror struct {
	Devices []string `yaml:"devices"`
}

func (BootDeviceMirror) Validate

func (m BootDeviceMirror) Validate(c path.ContextPath) (r report.Report)

type Config

type Config struct {
	base.Config `yaml:",inline"`
	BootDevice  BootDevice `yaml:"boot_device"`
}

func (Config) FieldFilters added in v0.19.0

func (c Config) FieldFilters() *cutil.FieldFilters

Return FieldFilters for this spec.

func (Config) ToIgn3_3

func (c Config) ToIgn3_3(options common.TranslateOptions) (types.Config, report.Report, error)

ToIgn3_3 translates the config to an Ignition config. It returns a report of any errors or warnings in the source and resultant config. If the report has fatal errors or it encounters other problems translating, an error is returned.

func (Config) ToIgn3_3Unvalidated

func (c Config) ToIgn3_3Unvalidated(options common.TranslateOptions) (types.Config, translate.TranslationSet, report.Report)

ToIgn3_3Unvalidated translates the config to an Ignition config. It also returns the set of translations it did so paths in the resultant config can be tracked back to their source in the source config. No config validation is performed on input or output.

Jump to